        // Pay interest on an account's balance.
        // Interest is added via creditInterest, which adds
        // one month's interest at the the current rate.
class PayInterestAccount extends BalanceAccount {
    // Interest is credited on a monthly basis.
    public static final int MONTHS_PER_YEAR = 12;
    public static final int PERCENT = 100;

    public PayInterestAccount(double initialRate)
                        throws RuntimeException {
        setRate(initialRate);
    }

        // Update the balance with one month's interest.
    public void creditInterest() throws RuntimeException {
        long balance = getBalance();
        // Interest payments are rounded down to the nearest cent.
        long interest = (long) (balance*getRate()/
                                (PERCENT*MONTHS_PER_YEAR));
        credit(interest);
    }

    public double getRate(){
        return rate;
    }

    public void setRate(double r) throws RuntimeException {
        if(r >= 0){
            rate = r;
        }
        else{
            throw new RuntimeException(
                        "A negative rate value is illegal: "+r);
        }
    }

    // The annual interest rate in percentage points.
    private double rate;
}
